@@ -40,6 +40,7 @@
 #include "db-itunes-parser.h"
 #include "db-parse-context.h"
 #include <glib/gi18n-lib.h>
+#include <glib/gstdio.h>
 
 typedef int (*ParseListItem)(DBParseContext *ctx, GError *error);
 
@@ -98,7 +99,7 @@ get_utf16_string (void* buffer, gint length, guint byte_order)
 }
 
 struct ParsedMhodString {
-        enum MhodType mhod_type;
+        enum MhodArtworkType mhod_type;
         char *mhod_string;
 };
 
@@ -542,14 +543,6 @@ mhfd_associate_itunesdb_artwork (DBParseContext *ctx)
 	}
 	else
 	{
-	    if ((track->artwork_size + track->artwork_count) !=
-		artwork->artwork_size)
-	    {
-		g_warning (_("iTunesDB and ArtworkDB artwork sizes inconsistent (%d+%d != %d)\n"),
-			   track->artwork_size,
-			   track->artwork_count,
-			   track->artwork->artwork_size);
-	    }
 	    itdb_artwork_free (track->artwork);
 	    track->artwork = itdb_artwork_duplicate (artwork);
 	}
@@ -679,7 +672,7 @@ ipod_db_get_artwork_db_path (const char *mount_point)
 		if (control_dir)
 		{
 		    gchar *dir = g_build_filename (control_dir, "Artwork", NULL);
-		    mkdir (dir, 0777);
+		    g_mkdir (dir, 0777);
 		    g_free (control_dir);
 		    g_free (dir);
 		    artwork_dir = itdb_get_artwork_dir (mount_point);
@@ -733,9 +726,6 @@ ipod_parse_artwork_db (Itdb_iTunesDB *itdb)
 	return 0;
 
  error:
-	if (ctx != NULL) {
-		db_parse_context_destroy (ctx);
-	}
 	return -1;
 }
 
@@ -760,7 +750,7 @@ ipod_db_get_photos_db_path (const char *mount_point)
 	    {
 		/* attempt to create Photos dir */
 		gchar *dir = g_build_filename (mount_point, "Photos", NULL);
-		mkdir (dir, 0777);
+		g_mkdir (dir, 0777);
 		g_free (dir);
 		photos_dir = itdb_get_photos_dir (mount_point);
 	    }
